Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2901)

Unified Diff: chrome_frame/chrome_frame_reporting.cc

Issue 465074: Added support for running reliability tests for ChromeFrame on similar lines ... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome_frame/chrome_frame.gyp ('k') | chrome_frame/crash_reporting/crash_report.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome_frame/chrome_frame_reporting.cc
===================================================================
--- chrome_frame/chrome_frame_reporting.cc (revision 34059)
+++ chrome_frame/chrome_frame_reporting.cc (working copy)
@@ -11,6 +11,7 @@
#include "chrome/installer/util/google_update_settings.h"
#include "chrome/installer/util/install_util.h"
#include "chrome_frame/chrome_frame_reporting.h"
+#include "chrome_frame/utils.h"
// Well known SID for the system principal.
const wchar_t kSystemPrincipalSid[] = L"S-1-5-18";
@@ -46,11 +47,13 @@
extern "C" IMAGE_DOS_HEADER __ImageBase;
bool InitializeCrashReporting() {
- // We want to use the Google Update crash reporting. We need to check if the
- // user allows it first.
- if (!GoogleUpdateSettings::GetCollectStatsConsent())
- return true;
-
+ // In headless mode we want crashes to be reported back.
+ if (!IsHeadlessMode()) {
+ // We want to use the Google Update crash reporting. We need to check if the
+ // user allows it first.
+ if (!GoogleUpdateSettings::GetCollectStatsConsent())
+ return true;
+ }
// Build the pipe name. It can be either:
// System-wide install: "NamedPipe\GoogleCrashServices\S-1-5-18"
// Per-user install: "NamedPipe\GoogleCrashServices\<user SID>"
« no previous file with comments | « chrome_frame/chrome_frame.gyp ('k') | chrome_frame/crash_reporting/crash_report.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698